==> open-xchange-core_7.2.1.orig.tar.bz2: open-xchange-core-7.2.1/com.openexchange.global/src/com/openexchange/i18n/I18nTranslator.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.i18n;

import java.util.Locale;
import org.apache.commons.logging.Log;
import com.openexchange.log.LogFactory;

/**
 * Implementation of a {@link Translator} backed with an {@link I18nService}.
 *
 * @author <a href="mailto:marcus.klein@open-xchange.com">Marcus Klein</a>
 */
public class I18nTranslator implements Translator {

    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(I18nTranslator.class));
    private static final boolean DEBUG_ENABLED = LOG.isDebugEnabled();
    private static final boolean WARN_ENABLED = LOG.isWarnEnabled();

    private final I18nService service;

    /**
     * Initializes a new {@link I18nTranslator}.
     *
     * @param service The i18n service
     */
    public I18nTranslator(final I18nService service) {
        super();
        this.service = service;
    }

    @Override
    public String translate(final String toTranslate) {
        if (!service.hasKey(toTranslate)) {
            final Locale locale = service.getLocale();
            if (isEnUs(locale)) {
                if (DEBUG_ENABLED) {
                    final String message = new com.openexchange.java.StringAllocator(64).append("I18n service for locale ").append(locale).append(
                        " has no translation for \"").append(toTranslate).append("\".").toString();
                    LOG.warn(message, new Throwable(message));
                }
            } else if (WARN_ENABLED) {
                LOG.warn(new com.openexchange.java.StringAllocator(64).append("I18n service for locale ").append(locale).append(" has no translation for \"").append(
                    toTranslate).append("\".").toString());
            }
            return toTranslate;
        }
        return service.getLocalized(toTranslate);
    }

    private static boolean isEnUs(final Locale locale) {
        if (null == locale) {
            return false;
        }
        return "en".equals(locale.getLanguage()) && "US".equals(locale.getCountry());
    }

}

==> open-xchange-core_7.4.2.orig.tar.bz2: open-xchange-core-7.4.2/com.openexchange.global/src/com/openexchange/i18n/I18nTranslator.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.i18n;

import java.util.Locale;

/**
 * Implementation of a {@link Translator} backed with an {@link I18nService}.
 *
 * @author <a href="mailto:marcus.klein@open-xchange.com">Marcus Klein</a>
 */
public class I18nTranslator implements Translator {

    private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(I18nTranslator.class);

    private final I18nService service;

    /**
     * Initializes a new {@link I18nTranslator}.
     *
     * @param service The i18n service
     */
    public I18nTranslator(final I18nService service) {
        super();
        this.service = service;
    }

    @Override
    public String translate(final String toTranslate) {
        if (!service.hasKey(toTranslate)) {
            final Locale locale = service.getLocale();
            if (isEnUs(locale)) {
                LOG.warn("I18n service for locale {} has no translation for \"{}\".", locale, toTranslate, new Throwable());
            } else {
                LOG.warn("I18n service for locale {} has no translation for \"{}\".", locale, toTranslate);
            }
            return toTranslate;
        }
        return service.getLocalized(toTranslate);
    }

    private static boolean isEnUs(final Locale locale) {
        if (null == locale) {
            return false;
        }
        return "en".equals(locale.getLanguage()) && "US".equals(locale.getCountry());
    }

}
